from __future__ import annotations

from .FXComposite import FXComposite
from .FXIcon import FXIcon
from .FXList import FXList
from .FXObject import FXObject

#: Don't automatically commit on double click.
AFXLIST_NO_AUTOCOMMIT: int = hash("AFXLIST_NO_AUTOCOMMIT")


class AFXList(FXList):
    """This class is a list widget that allows displaying items in a scrollable window.

    Each item has associated data set as integers as items are added.
    """

    def __init__(
        self,
        p: FXComposite,
        nvis: int,
        tgt: FXObject | None = None,
        sel: int = 0,
        opts: int = 0,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
    ):
        """Constructor.

        Parameters
        ----------
        p : FXComposite
            Parent widget.
        nvis : int
            Number of visible items.
        tgt : FXObject | None
            Message target.
        sel : int
            Message ID.
        opts : int
            Options and hints.
        x : int
            X coordinate of origin.
        y : int
            Y coordinate of origin.
        w : int
            Width of the widget.
        h : int
            Height of the widget.
        """

    def appendItem(self, text: str, icon: FXIcon | None = None, sel: int = 0):  # type: ignore
        """Adds a new item to the end of the list.

        Parameters
        ----------
        text : str
            Text
        icon : FXIcon | None
            Icon
        sel : int
            Integer associated with this item
        """

    def disable(self):
        """Disables the list.

        Reimplemented from FXWindow.
        """

    def enable(self):
        """Enables the list.

        Reimplemented from FXWindow.
        """

    def getAutoCommit(self):
        """Returns the auto-commit flag."""

    def getDefaultHeight(self):
        """Returns the default height of the list.

        Reimplemented from FXList.
        """

    def getItemIndexForData(self, data: str):
        """Returns the index of the first item with the associated data or -1 if not found.

        Parameters
        ----------
        data : str
        """

    def getItemProvider(self):
        """Returns the provider of the list's items."""

    def getSingleSelection(self):
        """Returns the index of the uniquely selected item.

        If more than one item or no items are selected, returns -1.
        """

    def insertItem(self, index: int, text: str, icon: FXIcon | None = None, sel: int = 0):  # type: ignore
        """Inserts a new item at the given index.

        Parameters
        ----------
        index : int
            Index
        text : str
            Text
        icon : FXIcon | None
            Icon
        sel : int
            Integer associated with this item
        """

    def replaceItem(self, index: int, text: str, icon: FXIcon | None = None, sel: int = 0):  # type: ignore
        """Replaces the item at the given index.

        Parameters
        ----------
        index : int
            Index
        text : str
            Text
        icon : FXIcon | None
            Icon
        sel : int
            Integer associated with this item
        """

    def setAutoCommit(self, commit: bool):
        """Sets the auto-commit option for handling double clicks. This option is turned on by default.

        Parameters
        ----------
        commit : bool
        """

    def setItemProvider(self, cp: FXObject):
        """Sets the provider of the list's items.

        Parameters
        ----------
        cp : FXObject
        """



from __future__ import annotations

from typing import List, Sequence, Union, overload

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..Sketcher.ConstrainedSketchVertex.ConstrainedSketchVertex import (
    ConstrainedSketchVertex,
)
from ..UtilityAndView.abaqusConstants import Boolean
from .Vertex import Vertex


@abaqus_class_doc
class VertexArray(List[Vertex]):
    """The VertexArray is a sequence of ConstrainedSketchVertex objects. If the part is modified, then
    VertexArray must be updated for that part.

    .. note::
        This object can be accessed by::

            import part
            mdb.models[name].parts[name].allInternalSets[name].vertices
            mdb.models[name].parts[name].allSets[name].vertices
            mdb.models[name].parts[name].sets[name].vertices
            mdb.models[name].parts[name].vertices
            import assembly
            mdb.models[name].rootAssembly.allInstances[name].sets[name].vertices
            mdb.models[name].rootAssembly.allInstances[name].vertices
            mdb.models[name].rootAssembly.allInternalSets[name].vertices
            mdb.models[name].rootAssembly.allSets[name].vertices
            mdb.models[name].rootAssembly.instances[name].sets[name].vertices
            mdb.models[name].rootAssembly.instances[name].vertices
            mdb.models[name].rootAssembly.modelInstances[i].sets[name].vertices
            mdb.models[name].rootAssembly.modelInstances[i].vertices
            mdb.models[name].rootAssembly.sets[name].vertices
            mdb.models[name].rootAssembly.vertices
    """

    @abaqus_method_doc
    def __init__(self, vertices: list[Vertex]):
        """This method creates a VertexArray object.

        .. note::
            This function can be accessed by::

                part.VertexArray

        Parameters
        ----------
        vertices
            A list of ConstrainedSketchVertex objects.

        Returns
        -------
        VertexArray
            A VertexArray object.
        """
        ...

    @overload
    @abaqus_method_doc
    def findAt(
        self,
        coordinates: tuple[float, float, float],
        printWarning: Boolean = True,
    ) -> ConstrainedSketchVertex:
        ...

    @overload
    @abaqus_method_doc
    def findAt(
        self,
        coordinates: tuple[tuple[float, float, float],],
        printWarning: Boolean = True,
    ) -> list[ConstrainedSketchVertex]:
        ...

    @overload
    @abaqus_method_doc
    def findAt(
        self,
        *coordinates: tuple[tuple[float, float, float],],
        printWarning: Boolean = True,
    ) -> list[ConstrainedSketchVertex]:
        ...

    @abaqus_method_doc
    def findAt(self, *args, **kwargs) -> Union[ConstrainedSketchVertex, list[ConstrainedSketchVertex]]:
        """This method returns the object or objects in the VertexArray located at the given coordinates. findAt
        initially uses the ACIS tolerance of 1E-6. As a result, findAt returns any ConstrainedSketchVertex
        object that is at the arbitrary point specified or at a distance of less than 1E-6 from the arbitrary
        point. If nothing is found, findAt uses the tolerance for imprecise geometry (applicable only for
        imprecise geometric entities). findAt will always try to find objects among all the vertices in the part
        or assembly instance and will not restrict itself to a subset even if the VertexArray represents such
        subset.

        Parameters
        ----------
        coordinates
            A sequence of Floats specifying the **X**, **Y**, and **Z** coordinates of the object to
            find.findAt returns either a ConstrainedSketchVertex object or a sequence of ConstrainedSketchVertex objects based on the
            type of input.

            * If **coordinates** is a sequence of Floats, findAt returns the ConstrainedSketchVertex object at that point.

            * If you omit the **coordinates** keyword argument, findAt accepts as arguments a sequence of sequence
              of floats in the following format::

                verts = v.findAt(((20.19686, -169.513997, 27.798593), ),
                                ((19.657627, -167.295749, 27.056402), ),
                                ((18.274129, -157.144741, 25.15218), ))
        printWarning
            A Boolean specifying whether a message is to be printed to the CLI if no entity is found
            at the specified location. The default value is True.

        Returns
        -------
        ConstrainedSketchVertex
            A ConstrainedSketchVertex object or a sequence of ConstrainedSketchVertex objects..
        """
        first_arg = kwargs.get("coordinates", args[0] if args else ((),))
        return ConstrainedSketchVertex() if isinstance(first_arg[0], float) else [ConstrainedSketchVertex()]

    @overload
    @abaqus_method_doc
    def getSequenceFromMask(self, mask: str) -> ConstrainedSketchVertex:  # type: ignore
        ...

    @overload
    @abaqus_method_doc
    def getSequenceFromMask(self, mask: Sequence[str]) -> list[ConstrainedSketchVertex]:  # type: ignore
        ...

    @abaqus_method_doc
    def getSequenceFromMask(
        self, mask: Union[str, Sequence[str]]
    ) -> Union[ConstrainedSketchVertex, list[ConstrainedSketchVertex]]:  # type: ignore
        """This method returns the object or objects in the VertexArray identified using the specified **mask**.
        This command is generated when the JournalOptions are set to COMPRESSEDINDEX. When a large number of
        objects are involved, this method is highly efficient.

        Parameters
        ----------
        mask
            A String specifying the object or objects.

        Returns
        -------
        ConstrainedSketchVertex | list[ConstrainedSketchVertex]
            A ConstrainedSketchVertex object or a sequence of ConstrainedSketchVertex objects..
        """
        return ConstrainedSketchVertex() if isinstance(mask, str) else [ConstrainedSketchVertex()]

    @abaqus_method_doc
    def getMask(self) -> str:
        """This method returns a string specifying the object or objects.

        Returns
        -------
        str
            A String specifying the object or objects.
        """
        return ""

    @abaqus_method_doc
    def getByBoundingBox(
        self,
        xMin: float = 0,
        yMin: float = 0,
        zMin: float = 0,
        xMax: float = 0,
        yMax: float = 0,
        zMax: float = 0,
    ) -> VertexArray:
        """This method returns an array of vertex objects that lie within the specified bounding box.

        Parameters
        ----------
        xMin
            A float specifying the minimum **X** boundary of the bounding box.
        yMin
            A float specifying the minimum **Y** boundary of the bounding box.
        zMin
            A float specifying the minimum **Z** boundary of the bounding box.
        xMax
            A float specifying the maximum **X** boundary of the bounding box.
        yMax
            A float specifying the maximum **Y** boundary of the bounding box.
        zMax
            A float specifying the maximum **Z** boundary of the bounding box.

        Returns
        -------
        VertexArray
            A VertexArray object, which is a sequence of ConstrainedSketchVertex objects..
        """
        return VertexArray([Vertex()])

    @abaqus_method_doc
    def getByBoundingCylinder(self, center1: tuple, center2: tuple, radius: str) -> VertexArray:
        """This method returns an array of vertex objects that lie within the specified bounding cylinder.

        Parameters
        ----------
        center1
            A tuple of the **X**, **Y**, and **Z** coordinates of the center of the first end of the
            cylinder.
        center2
            A tuple of the **X**, **Y**, and **Z** coordinates of the center of the second end of the
            cylinder.
        radius
            A float specifying the radius of the cylinder.

        Returns
        -------
        VertexArray
            A VertexArray object, which is a sequence of ConstrainedSketchVertex objects..
        """
        return VertexArray([Vertex()])

    @abaqus_method_doc
    def getByBoundingSphere(self, center: tuple, radius: str) -> VertexArray:
        """This method returns an array of vertex objects that lie within the specified bounding sphere.

        Parameters
        ----------
        center
            A tuple of the **X**, **Y**, and **Z** coordinates of the center of the sphere.
        radius
            A float specifying the radius of the sphere.

        Returns
        -------
        VertexArray
            A VertexArray object, which is a sequence of ConstrainedSketchVertex objects..
        """
        return VertexArray([Vertex()])

    @abaqus_method_doc
    def getBoundingBox(self) -> dict[str, tuple[float, float, float]]:
        """This method returns a dictionary of two tuples representing minimum and maximum boundary values of
        the bounding box of the minimum size containing the vertex sequence.

        Returns
        -------
        dict[str, tuple[float, float, float]]
            A Dictionary object with the following items:

            - **low**: a tuple of three floats representing the minimum **X** -, **Y** -, and **Z** -boundary
              values of the bounding box.
            - **high**: a tuple of three floats representing the maximum **X** -, **Y** -, and **Z** -boundary
              values of the bounding box.
        """
        return {"low": (0.0, 0.0, 0.0), "high": (0.0, 0.0, 0.0)}

    @abaqus_method_doc
    def getClosest(self, coordinates: tuple, searchTolerance: str = "") -> dict[int, tuple[Vertex, tuple]]:
        """This method returns a object or objects in the VertexArray closest to the given set of points, where
        the given points need not lie on ConstrainedSketchVertex objects in the VertexArray.

        Parameters
        ----------
        coordinates
            A sequence of a sequence of floats, where each sequence of floats describes the **X**,
            **Y**, and **Z** coordinates of a point::

                >>> r=v.getClosest(coordinates=((20.0, 20.0, 10.0),(-1.0, -15.0, 15), ))
                >>> r.keys()
                [0, 1]
                >>> r[0]
                (mdb.models['Model-1'].parts['Part-1'].vertices[0], (15.7090625762939, 29.1666641235352, 20.0))
        searchTolerance
            A double specifying the distance within which the closest object must lie. The default
            value is half of the parent part/instance size.

        Returns
        -------
        dict
            This method returns a dictionary object. The key to the dictionary object is the
            position of the input point in the tuple specified in the **coordinates** starting at
            index 0. If a closest vertex could be found then the value is a sequence consisting of
            two objects. The first object in the sequence is a ConstrainedSketchVertex that is close to the input
            point referred to by the key. The second object in the sequence is a sequence of floats
            that specifies the **X**, **Y**, and **Z**  location of the ConstrainedSketchVertex. See program listing
            above.

        Raises
        ------
        Error
            The mask results in an empty sequence, An exception occurs if the resulting sequence is empty.
        """
        return {0: (Vertex(), (0.0, 0.0, 0.0))}



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import DEFAULT_MODEL, SymbolicConstant
from .Leaf import Leaf


@abaqus_class_doc
class LeafFromPartInstance(Leaf):
    """The LeafFromPartInstance object can be used whenever a Leaf object is expected as an argument. Leaf
    objects are used to specify the items in a display group. Leaf objects are constructed as temporary objects,
    which are then used as arguments to DisplayGroup commands. The LeafFromPartInstance object is derived from
    the Leaf object.

    .. note::
        This object can be accessed by::

            import displayGroupOdbToolset
    """

    #: A SymbolicConstant specifying the leaf type. Possible values are EMPTY_LEAF,
    #: DEFAULT_MODEL, ALL_ELEMENTS, ALL_NODES, and ALL_SURFACES.
    leafType: SymbolicConstant

    #: A sequence of Strings specifying the names of the part instances.
    partInstanceName: tuple

    @abaqus_method_doc
    def __init__(self, partInstanceName: tuple):
        """This method creates a Leaf object from a list of part instance names.

        .. note::
            This function can be accessed by::

                LeafFromPartInstance

        Parameters
        ----------
        partInstanceName
            A sequence of Strings specifying the names of the part instances.

        Returns
        -------
        LeafFromPartInstance
            A LeafFromPartInstance object.
        """
        super().__init__(DEFAULT_MODEL)



from __future__ import annotations

from typing import Any

from .FXApp import FXApp
from .FXColor import FXColor
from .FXImage import FXImage


class FXIcon(FXImage):
    """Icon class."""

    def __init__(self, a: FXApp, pix: Any | None = None, clr: FXColor | int = 0, opts: int = 0, w: int = 1, h: int = 1):
        """Create an icon with an initial pixel buffer pix, a transparent color clr, and options as in FXImage.

        Parameters
        ----------
        a : FXApp

        pix : Any | None

        clr : FXColor

        opts : int

        w : int

        h : int
        """

    def create(self):
        """Create the icon resource.

        Reimplemented from FXImage.
        """

    def destroy(self):
        """Destroy the icon resource.

        Reimplemented from FXImage.
        """

    def detach(self):
        """Detach the icon resource.

        Reimplemented from FXImage.
        """

    def render(self):
        """Render the image from client-side pixel buffer.

        Reimplemented from FXImage.
        """

    def resize(self, w: int, h: int):
        """Resize pixmap to the specified width and height. Reimplemented from FXImage.

        Parameters
        ----------
        w : int

        h : int
        """



from __future__ import annotations

from .FXColor import FXColor
from .FXComposite import FXComposite
from .FXFont import FXFont
from .FXIcon import FXIcon
from .FXIconItem import FXIconItem
from .FXIconListSortFunc import FXIconListSortFunc
from .FXObject import FXObject
from .FXScrollArea import FXScrollArea

#: Extended selection mode.
ICONLIST_EXTENDEDSELECT: int = hash("ICONLIST_EXTENDEDSELECT")

#: At most one selected item.
ICONLIST_SINGLESELECT: int = hash("ICONLIST_SINGLESELECT")

#: Always exactly one selected item.
ICONLIST_BROWSESELECT: int = hash("ICONLIST_BROWSESELECT")

#: Multiple selection mode.
ICONLIST_MULTIPLESELECT: int = hash("ICONLIST_MULTIPLESELECT")

#: Automatically size item spacing.
ICONLIST_AUTOSIZE: int = hash("ICONLIST_AUTOSIZE")

#: List mode.
ICONLIST_DETAILED: int = hash("ICONLIST_DETAILED")

#: Mini Icon mode.
ICONLIST_MINI_ICONS: int = hash("ICONLIST_MINI_ICONS")

#: Big Icon mode.
ICONLIST_BIG_ICONS: int = hash("ICONLIST_BIG_ICONS")

#: Row-wise mode.
ICONLIST_ROWS: int = hash("ICONLIST_ROWS")

#: Column-wise mode.
ICONLIST_COLUMNS: int = hash("ICONLIST_COLUMNS")

#: Normal icon list style.
ICONLIST_NORMAL: int = hash("ICONLIST_NORMAL")


class FXIconList(FXScrollArea):
    """Icon List Widget."""

    def __init__(
        self,
        p: FXComposite,
        tgt: FXObject | None = None,
        sel: int = 0,
        opts: int = ICONLIST_NORMAL,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
    ):
        """Construct icon list.

        Parameters
        ----------
        p : FXComposite

        tgt : FXObject | None

        sel : int

        opts : int

        x : int

        y : int

        w : int

        h : int
        """

    def appendItem(self, item: FXIconItem, notify: bool = False):
        """Append a [possibly subclassed] item to the end of the list.

        Parameters
        ----------
        item : FXIconItem

        notify : bool
        """

    def canFocus(self):
        """Icon list can receive focus.

        Reimplemented from FXWindow.
        """

    def clearItems(self, notify: bool = False):
        """Remove all items from list.

        Parameters
        ----------
        notify : bool
        """

    def create(self):
        """Create server-side resources.

        Reimplemented from FXComposite. Reimplemented in FXFileList.
        """

    def deselectItem(self, index: int, notify: bool = False):
        """Deselect item at index.

        Parameters
        ----------
        index : int

        notify : bool
        """

    def detach(self):
        """Detach server-side resources.

        Reimplemented from FXComposite. Reimplemented in FXFileList.
        """

    def disableItem(self, index: int):
        """Disable item at index.

        Parameters
        ----------
        index : int
        """

    def enableItem(self, index: int):
        """Enable item at index.

        Parameters
        ----------
        index : int
        """

    def extendSelection(self, index: int, notify: bool = False):
        """Extend selection from anchor index to index.

        Parameters
        ----------
        index : int

        notify : bool
        """

    def findItem(self, text: str, start: int = -1):
        """Search items for item by name, starting from start item; the flags argument controls the search
        direction, and case sensitivity.

        Parameters
        ----------
        text : str

        start : int
        """

    def getAnchorItem(self):
        """Return anchor item index, or -1 if none."""

    def getContentHeight(self):
        """Return content height.

        Reimplemented from FXScrollArea.
        """

    def getContentWidth(self):
        """Compute and return content width.

        Reimplemented from FXScrollArea.
        """

    def getCurrentItem(self):
        """Return current item index, or -1 if none."""

    def getCursorItem(self):
        """Return index of item under cursor, or -1 if none."""

    def getFont(self):
        """Return text font."""

    def getHelpText(self):
        """Get the status line help text for this widget."""

    def getItemAt(self, x: int, y: int):
        """Return index of item at x,y, or -1 if none.

        Parameters
        ----------
        x : int

        y : int
        """

    def getItemBigIcon(self, index: int):
        """Return big icon of item at index.

        Parameters
        ----------
        index : int
        """

    def getItemData(self, index: int):
        """Return item user-data pointer.

        Parameters
        ----------
        index : int
        """

    def getItemHeight(self):
        """Return item height."""

    def getItemMiniIcon(self, index: int):
        """Return mini icon of item at index.

        Parameters
        ----------
        index : int
        """

    def getItemSpace(self):
        """Return maximum item space."""

    def getItemText(self, index: int):
        """Return item text.

        Parameters
        ----------
        index : int
        """

    def getItemWidth(self):
        """Return item width."""

    def getListStyle(self):
        """Get the current icon list style."""

    def getNumCols(self):
        """Return number of columns."""

    def getNumItems(self):
        """Return number of items."""

    def getNumRows(self):
        """Return number of rows."""

    def getSelBackColor(self):
        """Return selected text background."""

    def getSelTextColor(self):
        """Return selected text color."""

    def getSortFunc(self):
        """Return sort function."""

    def getTextColor(self):
        """Return normal text color."""

    def getViewportHeight(self):
        """Return viewport size.

        Reimplemented from FXScrollArea.
        """

    def hitItem(self, index: int, x: int, y: int, ww: int = 1, hh: int = 1):
        """Return item hit code: 0 outside, 1 icon, 2 text.

        Parameters
        ----------
        index : int

        x : int

        y : int

        ww : int

        hh : int

        """

    def insertItem(self, index: int, item: FXIconItem, notify: bool = False):
        """Insert a new [possibly subclassed] item at the give index.

        Parameters
        ----------
        index : int

        item : FXIconItem

        notify : bool
        """

    def isItemCurrent(self, index: int):
        """Return True if item at index is current.

        Parameters
        ----------
        index : int
        """

    def isItemEnabled(self, index: int):
        """Return True if item at index is enabled.

        Parameters
        ----------
        index : int
        """

    def isItemSelected(self, index: int):
        """Return True if item at index is selected.

        Parameters
        ----------
        index : int
        """

    def isItemVisible(self, index: int):
        """Return True if item at index is visible.

        Parameters
        ----------
        index : int
        """

    def killFocus(self):
        """Remove the focus from this window.

        Reimplemented from FXWindow.
        """

    def killSelection(self, notify: bool = False):
        """Deselect all items.

        Parameters
        ----------
        notify : bool
        """

    def makeItemVisible(self, index: int):
        """Scroll to make item at index visible.

        Parameters
        ----------
        index : int
        """

    def moveContents(self, x: int, y: int):
        """Move contents to the specified position. Reimplemented from FXScrollArea.

        Parameters
        ----------
        x : int

        y : int
        """

    def position(self, x: int, y: int, w: int, h: int):
        """Move and resize this window in the parent's coordinates. Reimplemented from FXWindow.

        Parameters
        ----------
        x : int

        y : int

        w : int

        h : int
        """

    def prependItem(self, item: FXIconItem, notify: bool = False):
        """Append a [possibly subclassed] item to the end of the list.

        Parameters
        ----------
        item : FXIconItem

        notify : bool
        """

    def recalc(self):
        """Recalculate layout.

        Reimplemented from FXWindow.
        """

    def removeItem(self, index: int, notify: bool = False):
        """Remove item from list.

        Parameters
        ----------
        index : int

        notify : bool
        """

    def replaceItem(self, index: int, item: FXIconItem, notify: bool = False):
        """Replace the item with a [possibly subclassed] item.

        Parameters
        ----------
        index : int

        item : FXIconItem

        notify : bool
        """

    def resize(self, w: int, h: int):
        """Resize this window to the specified width and height. Reimplemented from FXWindow.

        Parameters
        ----------
        w : int

        h : int
        """

    def retrieveItem(self, index: int):
        """Return the item at the given index.

        Parameters
        ----------
        index : int
        """

    def selectInRectangle(self, x: int, y: int, w: int, h: int, notify: bool = False):
        """Select items in rectangle.

        Parameters
        ----------
        x : int

        y : int

        w : int

        h : int

        notify : bool
        """

    def selectItem(self, index: int, notify: bool = False):
        """Select item at index.

        Parameters
        ----------
        index : int

        notify : bool
        """

    def setAnchorItem(self, index: int):
        """Change anchor item index.

        Parameters
        ----------
        index : int
        """

    def setCurrentItem(self, index: int, notify: bool = False):
        """Change current item index.

        Parameters
        ----------
        index : int

        notify : bool
        """

    def setFocus(self):
        """Move the focus to this window.

        Reimplemented from FXWindow.
        """

    def setFont(self, fnt: FXFont):
        """Change text font.

        Parameters
        ----------
        fnt : FXFont
        """

    def setHelpText(self, text: str):
        """Set the status line help text for this widget.

        Parameters
        ----------
        text : str
        """

    def setItemBigIcon(self, index: int, icon: FXIcon):
        """Change item big icon.

        Parameters
        ----------
        index : int

        icon : FXIcon
        """

    def setItemData(self, index: int, ptr: str):
        """Change item user-data pointer.

        Parameters
        ----------
        index : int

        ptr : str
        """

    def setItemMiniIcon(self, index: int, icon: FXIcon):
        """Change item mini icon.

        Parameters
        ----------
        index : int

        icon : FXIcon
        """

    def setItemSpace(self, s: int):
        """Change maximum item space for each item.

        Parameters
        ----------
        s : int
        """

    def setItemText(self, index: int, text: str):
        """Change item text.

        Parameters
        ----------
        index : int

        text : str
        """

    def setListStyle(self, style: int):
        """Set the current icon list style.

        Parameters
        ----------
        style : int
        """

    def setSelBackColor(self, clr: FXColor):
        """Change selected text background.

        Parameters
        ----------
        clr : FXColor
        """

    def setSelTextColor(self, clr: FXColor):
        """Change selected text color.

        Parameters
        ----------
        clr : FXColor
        """

    def setSortFunc(self, func: FXIconListSortFunc):
        """Change sort function.

        Parameters
        ----------
        func : FXIconListSortFunc
        """

    def setTextColor(self, clr: FXColor):
        """Change normal text color.

        Parameters
        ----------
        clr : FXColor
        """

    def sortItems(self):
        """Sort items."""

    def toggleItem(self, index: int, notify: bool = False):
        """Toggle item at index.

        Parameters
        ----------
        index : int

        notify : bool
        """

    def updateItem(self, index: int):
        """Repaint item at index.

        Parameters
        ----------
        index : int
        """



from __future__ import annotations

from .AFXGuiObjectManager import AFXGuiObjectManager
from .FXComposite import FXComposite
from .FXIcon import FXIcon
from .FXMenuCascade import FXMenuCascade
from .FXPopup import FXPopup


class AFXMenuCascade(FXMenuCascade):
    """This class provides the interface for creating an FXMenuCascade and performing various management
    activities on it.

    It will use utility methods so the menu cascade is correctly managed for modules and toolsets.
    """

    def __init__(
        self,
        owner: AFXGuiObjectManager,
        p: FXComposite,
        label: str,
        ic: FXIcon | None = None,
        popup: FXPopup | None = None,
    ):
        """Constructor.

        Parameters
        ----------
        owner : AFXGuiObjectManager
            Creator of the menu cascade.
        p : FXComposite
            Parent widget.
        label : str
            Label for the menu button.
        ic : FXIcon | None
            Menu button icon.
        popup : FXPopup | None
            Menu cascade's pullright pane.
        """

    def getOwner(self):
        """Returns the owner of the menu cascade.

        Reimplemented from FXWindow.
        """



from __future__ import annotations

from typing import Sequence, Union

from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import (
    ALL,
    DEFAULT,
    EVERY_TIME_INCREMENT,
    EXCLUDE,
    J_INTEGRAL,
    MODEL,
    MTS,
    OFF,
    PRESELECT,
    Boolean,
)
from ..UtilityAndView.abaqusConstants import abaqusConstants as C


@abaqus_class_doc
class HistoryOutputRequest:
    """The HistoryOutputRequest object defines a history output request.

    .. note::
        This object can be accessed by::

            import step
            mdb.models[name].historyOutputRequests[name]

        The corresponding analysis keywords are:

        - CONTACT OUTPUT
        - ELEMENT OUTPUT
        - ENERGY OUTPUT
        - CONTACT OUTPUT
        - ELEMENT OUTPUT
        - ENERGY OUTPUT
        - MODAL OUTPUT
        - CONTACT OUTPUT
        - ELEMENT OUTPUT
        - OUTPUT
        - RADIATION OUTPUT
    """

    #: A String specifying a bolt load from which output is requested. The default value is an
    #: empty string.
    boltLoad: str = ""

    #: The SymbolicConstant MODEL or a Region object specifying the region from which output is
    #: requested. The SymbolicConstant MODEL represents the whole model. The default value is
    #: MODEL.If the region is a surface region, the surface must lie within the general contact
    #: surface domain.
    region: Union[Literal[C.MODEL], Region] = MODEL

    #: The SymbolicConstant DEFAULT or a tuple of Ints specifying the section points for which
    #: output is requested. The default value is DEFAULT.
    sectionPoints: Union[Literal[C.DEFAULT], Sequence[int]] = DEFAULT

    #: None or a tuple of Strings specifying the interaction names. The default value is
    #: None.The sequence can contain only one String.
    interactions: tuple | None = None

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        region: Union[Literal[C.MODEL], Region] = MODEL,
        variables: Union[Sequence[str], Literal[C.PRESELECT, C.ALL]] = PRESELECT,
        frequency: Union[int, Literal[C.LAST_INCREMENT]] = 1,
        modes: Union[Literal[C.ALL], Sequence[int]] = ALL,
        timeInterval: Union[Literal[C.EVERY_TIME_INCREMENT], float] = EVERY_TIME_INCREMENT,
        numIntervals: int = 20,
        boltLoad: str = "",
        sectionPoints: Union[Literal[C.DEFAULT], Sequence[int]] = DEFAULT,
        stepName: str = "",
        interactions: str | None = None,
        contourIntegral: str | None = None,
        numberOfContours: int = 0,
        stressInitializationStep: str | None = None,
        contourType: Literal[C.J_INTEGRAL, C.C_INTEGRAL, C.T_STRESS, C.K_FACTORS] = J_INTEGRAL,
        kFactorDirection: Literal[C.MTS, C.MERR, C.K110] = MTS,
        rebar: Literal[C.EXCLUDE, C.INCLUDE, C.ONLY] = EXCLUDE,
        integratedOutputSection: str = "",
        springs: tuple | None = None,
        filter: Literal[C.ANTIALIASING] | None = None,
        fasteners: str = "",
        assembledFastener: str = "",
        assembledFastenerSet: str = "",
        sensor: Boolean = OFF,
        useGlobal: Boolean = True,
    ) -> None:
        """This method creates a HistoryOutputRequest object.

        .. note::
            This function can be accessed by::

                mdb.models[name].HistoryOutputRequest

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the object is created.
        region
            The SymbolicConstant MODEL or a Region object specifying the region from which output is
            requested. The SymbolicConstant MODEL represents the whole model. The default value is
            MODEL.If the region is a surface region, the surface must lie within the general contact
            surface domain.
        variables
            A sequence of Strings specifying output request variable or component names, or the
            SymbolicConstant PRESELECT or ALL. PRESELECT represents all default output variables for
            the given step. ALL represents all valid output variables. The default value is
            PRESELECT.
        frequency
            The SymbolicConstant LAST_INCREMENT or an Int specifying the output frequency in
            increments. The default value is 1.
        modes
            The SymbolicConstant ALL or a sequence of Ints specifying a list of eigenmodes for which
            output is desired. The default value is ALL.
        timeInterval
            The SymbolicConstant EVERY_TIME_INCREMENT or a Float specifying the time interval at
            which the output states are to be written. The default value is EVERY_TIME_INCREMENT.
        numIntervals
            An Int specifying the number of intervals during the step at which output database
            states are to be written. The default value is 20.
        boltLoad
            A String specifying a bolt load from which output is requested. The default value is an
            empty string.
        sectionPoints
            The SymbolicConstant DEFAULT or a sequence of Ints specifying the section points for
            which output is requested. The default value is DEFAULT.
        stepName
            A String specifying the name of the step. The default value is an empty string.
        interactions
            None or a sequence of Strings specifying the interaction names. The default value is
            None.The sequence can contain only one String.
        contourIntegral
            A String specifying the contour integral name. The default value is None.
        numberOfContours
            An Int specifying the number of contour integrals to output for the contour integral
            object. The default value is 0.
        stressInitializationStep
            A String specifying the name of the stress initialization step. The default value is
            None.
        contourType
            A SymbolicConstant specifying the type of contour integral. Possible values are
            J_INTEGRAL, C_INTEGRAL, T_STRESS, and K_FACTORS. The default value is J_INTEGRAL.
        kFactorDirection
            A SymbolicConstant specifying the stress intensity factor direction. Possible values are
            MTS, MERR, and K110. The **kFactorDirection** argument is valid only if
            **contourType** = K_FACTORS. The default value is MTS.
        rebar
            A SymbolicConstant specifying whether output is requested for rebar. Possible values are
            EXCLUDE, INCLUDE, and ONLY. The default value is EXCLUDE.
        integratedOutputSection
            A String specifying the integrated output section. The default value is an empty string.
        springs
            A sequence of Strings specifying the springs/dashpots names. The default value is None.
            The sequence can contain only one String.
        filter
            The SymbolicConstant ANTIALIASING or a String specifying the name of an output filter
            object. The default value is None.
        fasteners
            A String specifying the fastener name. The default value is an empty string.
        assembledFastener
            A String specifying the assembled fastener name. The default value is an empty string.
        assembledFastenerSet
            A String specifying the set name from the model referenced by the assembled fastener,
            **assembledFastener**. The default value is an empty string.
        sensor
            A Boolean specifying whether to associate the output request with a sensor definition.
            The default value is OFF.
        useGlobal
            A Boolean specifying whether to output vector-valued nodal variables in the global
            directions. The default value is True.
        """
        ...

    @abaqus_method_doc
    def deactivate(self, stepName: str) -> None:
        """This method deactivates the history output request in the specified step and all subsequent steps.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the history output request is
            deactivated.
        """
        ...

    @abaqus_method_doc
    def move(self, fromStepName: str, toStepName: str) -> None:
        """This method moves the history output request state object from one step to a different step.

        Parameters
        ----------
        fromStepName
            A String specifying the name of the step from which the history output request state is
            moved.
        toStepName
            A String specifying the name of the step to which the history output request state is
            moved.
        """
        ...

    @abaqus_method_doc
    def reset(self, stepName: str) -> None:
        """This method resets the history output request state of the specified step to the state of the
        previous step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the history output request state is
            reset.
        """
        ...

    @abaqus_method_doc
    def resume(self) -> None:
        """This method resumes the history output request that was previously suppressed."""
        ...

    @abaqus_method_doc
    def suppress(self) -> None:
        """This method suppresses the history output request."""
        ...

    @abaqus_method_doc
    def setValues(
        self,
        region: Union[Literal[C.MODEL], Region] = MODEL,
        variables: Union[Sequence[str], Literal[C.PRESELECT, C.ALL]] = PRESELECT,
        frequency: Union[int, Literal[C.LAST_INCREMENT]] = 1,
        modes: Union[Literal[C.ALL], Sequence[int]] = ALL,
        timeInterval: Union[Literal[C.EVERY_TIME_INCREMENT], float] = EVERY_TIME_INCREMENT,
        numIntervals: int = 20,
        boltLoad: str = "",
        sectionPoints: Union[Literal[C.DEFAULT], Sequence[int]] = DEFAULT,
        stepName: str = "",
        interactions: str | None = None,
        contourIntegral: str | None = None,
        numberOfContours: int = 0,
        stressInitializationStep: str | None = None,
        contourType: Literal[C.J_INTEGRAL, C.C_INTEGRAL, C.T_STRESS, C.K_FACTORS] = J_INTEGRAL,
        kFactorDirection: Literal[C.MTS, C.MERR, C.K110] = MTS,
        rebar: Literal[C.EXCLUDE, C.INCLUDE, C.ONLY] = EXCLUDE,
        integratedOutputSection: str = "",
        springs: tuple | None = None,
        filter: Literal[C.ANTIALIASING] | None = None,
        fasteners: str = "",
        assembledFastener: str = "",
        assembledFastenerSet: str = "",
        sensor: Boolean = OFF,
        useGlobal: Boolean = True,
    ) -> None:
        """This method modifies the data for an existing HistoryOutputRequest object in the step where it is
        created.

        Parameters
        ----------
        region
            The SymbolicConstant MODEL or a Region object specifying the region from which output is
            requested. The SymbolicConstant MODEL represents the whole model. The default value is
            MODEL.If the region is a surface region, the surface must lie within the general contact
            surface domain.
        variables
            A sequence of Strings specifying output request variable or component names, or the
            SymbolicConstant PRESELECT or ALL. PRESELECT represents all default output variables for
            the given step. ALL represents all valid output variables. The default value is
            PRESELECT.
        frequency
            The SymbolicConstant LAST_INCREMENT or an Int specifying the output frequency in
            increments. The default value is 1.
        modes
            The SymbolicConstant ALL or a sequence of Ints specifying a list of eigenmodes for which
            output is desired. The default value is ALL.
        timeInterval
            The SymbolicConstant EVERY_TIME_INCREMENT or a Float specifying the time interval at
            which the output states are to be written. The default value is EVERY_TIME_INCREMENT.
        numIntervals
            An Int specifying the number of intervals during the step at which output database
            states are to be written. The default value is 20.
        boltLoad
            A String specifying a bolt load from which output is requested. The default value is an
            empty string.
        sectionPoints
            The SymbolicConstant DEFAULT or a sequence of Ints specifying the section points for
            which output is requested. The default value is DEFAULT.
        stepName
            A String specifying the name of the step. The default value is an empty string.
        interactions
            None or a sequence of Strings specifying the interaction names. The default value is
            None.The sequence can contain only one String.
        contourIntegral
            A String specifying the contour integral name. The default value is None.
        numberOfContours
            An Int specifying the number of contour integrals to output for the contour integral
            object. The default value is 0.
        stressInitializationStep
            A String specifying the name of the stress initialization step. The default value is
            None.
        contourType
            A SymbolicConstant specifying the type of contour integral. Possible values are
            J_INTEGRAL, C_INTEGRAL, T_STRESS, and K_FACTORS. The default value is J_INTEGRAL.
        kFactorDirection
            A SymbolicConstant specifying the stress intensity factor direction. Possible values are
            MTS, MERR, and K110. The **kFactorDirection** argument is valid only if
            **contourType** = K_FACTORS. The default value is MTS.
        rebar
            A SymbolicConstant specifying whether output is requested for rebar. Possible values are
            EXCLUDE, INCLUDE, and ONLY. The default value is EXCLUDE.
        integratedOutputSection
            A String specifying the integrated output section. The default value is an empty string.
        springs
            A sequence of Strings specifying the springs/dashpots names. The default value is None.
            The sequence can contain only one String.
        filter
            The SymbolicConstant ANTIALIASING or a String specifying the name of an output filter
            object. The default value is None.
        fasteners
            A String specifying the fastener name. The default value is an empty string.
        assembledFastener
            A String specifying the assembled fastener name. The default value is an empty string.
        assembledFastenerSet
            A String specifying the set name from the model referenced by the assembled fastener,
            **assembledFastener**. The default value is an empty string.
        sensor
            A Boolean specifying whether to associate the output request with a sensor definition.
            The default value is OFF.
        useGlobal
            A Boolean specifying whether to output vector-valued nodal variables in the global
            directions. The default value is True.
        """
        ...

    @abaqus_method_doc
    def setValuesInStep(
        self,
        stepName: str,
        variables: Union[Sequence[str], Literal[C.PRESELECT, C.ALL]] = ...,
        frequency: Union[int, Literal[C.LAST_INCREMENT]] = 1,
        modes: Union[Literal[C.ALL], Sequence[int]] = ALL,
        timeInterval: Union[Literal[C.EVERY_TIME_INCREMENT], float] = EVERY_TIME_INCREMENT,
        numIntervals: int = 20,
        timePoints: str | None = None,
    ) -> None:
        """This method modifies the propagating data for an existing HistoryOutputRequest object in the
        specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the history output request is
            modified.
        variables
            A sequence of Strings specifying output request variable or component names or the
            SymbolicConstant PRESELECT or ALL. PRESELECT represents all default output variables for
            the given step. ALL represents all valid output variables.
        frequency
            The SymbolicConstant LAST_INCREMENT or an Int specifying the output frequency in
            increments. The default value is 1.
        modes
            The SymbolicConstant ALL or a sequence of Ints specifying a list of eigenmodes for which
            output is desired. The default value is ALL.
        timeInterval
            The SymbolicConstant EVERY_TIME_INCREMENT or a Float specifying the time interval at
            which the output states are to be written. The default value is EVERY_TIME_INCREMENT.
        numIntervals
            An Int specifying the number of intervals during the step at which output database
            states are to be written. The default value is 20.
        timePoints
            A String specifying the name of a time point object. The default value is equal to the
            number of intervals during the step at which output database states are to be written.
            The default value is None.
        """
        ...



from __future__ import annotations

from abaqus.XY.XYDataCommands import (
    XYDataFromFile,
    XYDataFromFreeBody,
    XYDataFromHistory,
    XYDataFromPath,
    XYDataFromShellThickness,
    xyDataListFromField,
)

__all__ = [
    "XYDataFromFile",
    "XYDataFromHistory",
    "xyDataListFromField",
    "XYDataFromFreeBody",
    "XYDataFromShellThickness",
    "XYDataFromPath",
]



from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import (
    CURRENT,
    ELEMENT_CENTER_PROJECTION,
    GEOMETRY_ENHANCED,
    SECOND_ORDER_ADVECTION,
    UNIFORM,
    SymbolicConstant,
)
from ..UtilityAndView.abaqusConstants import abaqusConstants as C


@abaqus_class_doc
class AdaptiveMeshControl:
    r"""The AdaptiveMeshControl object is used to control various aspects of Arbitrary Lagrangian Eularian (ALE)
    style adaptive smoothing and advection algorithms applied to an ALE adaptive mesh domain.

    .. note::
        This object can be accessed by::

            import step
            mdb.models[name].adaptiveMeshControls[name]
    """

    #: A String specifying the name of the object.
    name: str

    #: A SymbolicConstant specifying the remapping algorithm. Possible values are
    #: FIRST_ORDER_ADVECTION and SECOND_ORDER_ADVECTION. The default value is
    #: SECOND_ORDER_ADVECTION.
    remapping: SymbolicConstant = SECOND_ORDER_ADVECTION

    #: A SymbolicConstant specifying the type of smoothing algorithm to use. Possible values
    #: are STANDARD and GEOMETRY_ENHANCED. The default value is GEOMETRY_ENHANCED.
    smoothingAlgorithm: SymbolicConstant = GEOMETRY_ENHANCED

    #: A SymbolicConstant specifying the type of smoothing to perform. Possible values are
    #: UNIFORM and GRADED. The default value is UNIFORM.
    smoothingPriority: SymbolicConstant = UNIFORM

    #: A Float specifying the initial geometric feature angle, :math:`\theta_I`, in degrees. Possible values
    #: are :math:`0^\circ\le\theta_I\le 180^\circ`. The default value is 30.0.
    initialFeatureAngle: float = 30

    #: A Float specifying the transitional feature angle, :math:`\theta_T`, in degrees. Possible values are
    #: :math:`0^\circ\le\theta_T\le 180^\circ`. The default value is 30.0.
    transitionFeatureAngle: float = 30

    #: A SymbolicConstant specifying the type of momentum advection algorithm. Possible values
    #: are ELEMENT_CENTER_PROJECTION and HALF_INDEX_SHIFT. The default value is
    #: ELEMENT_CENTER_PROJECTION.
    momentumAdvection: SymbolicConstant = ELEMENT_CENTER_PROJECTION

    #: A SymbolicConstant specifying the nodal starting location to use for remeshing. Possible
    #: values are CURRENT and PREVIOUS. The default value is CURRENT.
    meshingPredictor: SymbolicConstant = CURRENT

    #: A Float specifying the solution dependence weight, :math:`\alpha_C`. Possible values are
    #: :math:`0.0\le\alpha_C\le 1.0`. The default value is 1.0.
    curvatureRefinement: float = 1

    #: A Float specifying the weight used by Abaqus/Explicit for the volumetric smoothing
    #: method. The default value is 1.0.
    volumetricSmoothingWeight: float = 1

    #: A Float specifying the weight for the Laplacian smoothing method. The default value is
    #: 0.0.
    laplacianSmoothingWeight: float = 0

    #: A Float specifying the weight for the equipotential smoothing method. The default value
    #: is 0.0.
    equipotentialSmoothingWeight: float = 0

    #: A Float specifying the initial geometric feature angle, :math:`\theta_C`. Possible values
    #: are :math:`0^\circ\le\theta_C\le 180^\circ`. The default value is 60.0.
    meshConstraintAngle: float = 60

    #: A Float specifying the weight for the original configuration projection method. The
    #: default value is 1.0.
    originalConfigurationProjectionWeight: float = 1

    #: A Float specifying the weight used by Abaqus/Standard for the volumetric smoothing
    #: method. The default value is 0.0.
    standardVolumetricSmoothingWeight: float = 0

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        remapping: Literal[C.SECOND_ORDER_ADVECTION, C.FIRST_ORDER_ADVECTION] = SECOND_ORDER_ADVECTION,
        smoothingAlgorithm: Literal[C.GEOMETRY_ENHANCED, C.STANDARD] = GEOMETRY_ENHANCED,
        smoothingPriority: Literal[C.GRADED, C.UNIFORM] = UNIFORM,
        initialFeatureAngle: float = 30,
        transitionFeatureAngle: float = 30,
        momentumAdvection: Literal[C.HALF_INDEX_SHIFT, C.ELEMENT_CENTER_PROJECTION] = ELEMENT_CENTER_PROJECTION,
        meshingPredictor: Literal[C.PREVIOUS, C.CURRENT] = CURRENT,
        curvatureRefinement: float = 1,
        volumetricSmoothingWeight: float = 1,
        laplacianSmoothingWeight: float = 0,
        equipotentialSmoothingWeight: float = 0,
        meshConstraintAngle: float = 60,
        originalConfigurationProjectionWeight: float = 1,
        standardVolumetricSmoothingWeight: float = 0,
    ):
        r"""This method creates an AdaptiveMeshControl object.

        .. note::
            This function can be accessed by::

                mdb.models[name].AdaptiveMeshControl

        Parameters
        ----------
        name
            A String specifying the name of the object.
        remapping
            A SymbolicConstant specifying the remapping algorithm. Possible values are
            FIRST_ORDER_ADVECTION and SECOND_ORDER_ADVECTION. The default value is
            SECOND_ORDER_ADVECTION.
        smoothingAlgorithm
            A SymbolicConstant specifying the type of smoothing algorithm to use. Possible values
            are STANDARD and GEOMETRY_ENHANCED. The default value is GEOMETRY_ENHANCED.
        smoothingPriority
            A SymbolicConstant specifying the type of smoothing to perform. Possible values are
            UNIFORM and GRADED. The default value is UNIFORM.
        initialFeatureAngle
            A Float specifying the initial geometric feature angle, :math:`\theta_I`, in degrees. Possible values
            are :math:`0^\circ\le\theta_I\le 180^\circ`. The default value is 30.0.
        transitionFeatureAngle
            A Float specifying the transitional feature angle, :math:`\theta_T`, in degrees. Possible values are
            :math:`0^\circ\le\theta_T\le 180^\circ`. The default value is 30.0.
        momentumAdvection
            A SymbolicConstant specifying the type of momentum advection algorithm. Possible values
            are ELEMENT_CENTER_PROJECTION and HALF_INDEX_SHIFT. The default value is
            ELEMENT_CENTER_PROJECTION.
        meshingPredictor
            A SymbolicConstant specifying the nodal starting location to use for remeshing. Possible
            values are CURRENT and PREVIOUS. The default value is CURRENT.
        curvatureRefinement
            A Float specifying the solution dependence weight, :math:`\alpha_C`. Possible values are
            :math:`0.0\le\alpha_C\le 1.0`. The default value is 1.0.
        volumetricSmoothingWeight
            A Float specifying the weight used by Abaqus/Explicit for the volumetric smoothing
            method. The default value is 1.0.
        laplacianSmoothingWeight
            A Float specifying the weight for the Laplacian smoothing method. The default value is
            0.0.
        equipotentialSmoothingWeight
            A Float specifying the weight for the equipotential smoothing method. The default value
            is 0.0.
        meshConstraintAngle
            A Float specifying the initial geometric feature angle, :math:`\theta_C`. Possible values
            are :math:`0^\circ\le\theta_C\le 180^\circ`. The default value is 60.0.
        originalConfigurationProjectionWeight
            A Float specifying the weight for the original configuration projection method. The
            default value is 1.0.
        standardVolumetricSmoothingWeight
            A Float specifying the weight used by Abaqus/Standard for the volumetric smoothing
            method. The default value is 0.0.

        Returns
        -------
        AdaptiveMeshControl
            An AdaptiveMeshControl object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(
        self,
        remapping: Literal[C.SECOND_ORDER_ADVECTION, C.FIRST_ORDER_ADVECTION] = SECOND_ORDER_ADVECTION,
        smoothingAlgorithm: Literal[C.GEOMETRY_ENHANCED, C.STANDARD] = GEOMETRY_ENHANCED,
        smoothingPriority: Literal[C.GRADED, C.UNIFORM] = UNIFORM,
        initialFeatureAngle: float = 30,
        transitionFeatureAngle: float = 30,
        momentumAdvection: Literal[C.HALF_INDEX_SHIFT, C.ELEMENT_CENTER_PROJECTION] = ELEMENT_CENTER_PROJECTION,
        meshingPredictor: Literal[C.PREVIOUS, C.CURRENT] = CURRENT,
        curvatureRefinement: float = 1,
        volumetricSmoothingWeight: float = 1,
        laplacianSmoothingWeight: float = 0,
        equipotentialSmoothingWeight: float = 0,
        meshConstraintAngle: float = 60,
        originalConfigurationProjectionWeight: float = 1,
        standardVolumetricSmoothingWeight: float = 0,
    ):
        r"""This method modifies the AdaptiveMeshControl object.

        Parameters
        ----------
        remapping
            A SymbolicConstant specifying the remapping algorithm. Possible values are
            FIRST_ORDER_ADVECTION and SECOND_ORDER_ADVECTION. The default value is
            SECOND_ORDER_ADVECTION.
        smoothingAlgorithm
            A SymbolicConstant specifying the type of smoothing algorithm to use. Possible values
            are STANDARD and GEOMETRY_ENHANCED. The default value is GEOMETRY_ENHANCED.
        smoothingPriority
            A SymbolicConstant specifying the type of smoothing to perform. Possible values are
            UNIFORM and GRADED. The default value is UNIFORM.
        initialFeatureAngle
            A Float specifying the initial geometric feature angle, :math:`\theta_I`, in degrees. Possible values
            are :math:`0^\circ\le\theta_I\le 180^\circ`. The default value is 30.0.
        transitionFeatureAngle
            A Float specifying the transitional feature angle, :math:`\theta_T`, in degrees. Possible values are
            :math:`0^\circ\le\theta_T\le 180^\circ`. The default value is 30.0.
        momentumAdvection
            A SymbolicConstant specifying the type of momentum advection algorithm. Possible values
            are ELEMENT_CENTER_PROJECTION and HALF_INDEX_SHIFT. The default value is
            ELEMENT_CENTER_PROJECTION.
        meshingPredictor
            A SymbolicConstant specifying the nodal starting location to use for remeshing. Possible
            values are CURRENT and PREVIOUS. The default value is CURRENT.
        curvatureRefinement
            A Float specifying the solution dependence weight, :math:`\alpha_C`. Possible values are
            :math:`0.0\le\alpha_C\le 1.0`. The default value is 1.0.
        volumetricSmoothingWeight
            A Float specifying the weight used by Abaqus/Explicit for the volumetric smoothing
            method. The default value is 1.0.
        laplacianSmoothingWeight
            A Float specifying the weight for the Laplacian smoothing method. The default value is
            0.0.
        equipotentialSmoothingWeight
            A Float specifying the weight for the equipotential smoothing method. The default value
            is 0.0.
        meshConstraintAngle
            A Float specifying the initial geometric feature angle, :math:`\theta_c`. Possible values are
            :math:`0^\circ\le\theta_C\le 180^\circ`. The default value is 60.0.
        originalConfigurationProjectionWeight
            A Float specifying the weight for the original configuration projection method. The
            default value is 1.0.
        standardVolumetricSmoothingWeight
            A Float specifying the weight used by Abaqus/Standard for the volumetric smoothing
            method. The default value is 0.0.

        Raises
        ------
        RangeError
        """
        ...



from __future__ import annotations

from .FXId import FXId


class FXDrawable(FXId):
    """Drawable is an abstract base class for any surface that can be drawn upon, such as a FXWindow, or
    FXImage."""

    def getHeight(self):
        """Height of drawable."""

    def getVisual(self):
        """Get the visual."""

    def getWidth(self):
        """Width of drawable."""

    def resize(self, w: int, h: int):
        """Resize drawable to the specified width and height. Reimplemented in FXBitmap, FXIcon, FXIconList,
        FXImage, FXMDIChild, FXRootWindow, FXText, FXTopWindow, and FXWindow.

        Parameters
        ----------
        w : int

        h : int
        """



from __future__ import annotations

from abaqus.TextRepresentation.textRepr import (
    getIndentedRepr,
    getPaths,
    prettyPrint,
    printPaths,
)

__all__ = [
    "getIndentedRepr",
    "getPaths",
    "prettyPrint",
    "printPaths",
]
